==> open-xchange-core_7.8.1.orig.tar.bz2: open-xchange-core-7.8.1/com.openexchange.server/src/com/openexchange/mail/json/actions/FolderInfo.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mail.json.actions;

import com.openexchange.exception.OXException;
import com.openexchange.mail.api.IMailFolderStorage;
import com.openexchange.mail.api.IMailFolderStorageEnhanced;
import com.openexchange.mail.api.IMailFolderStorageEnhanced2;
import com.openexchange.mail.dataobjects.MailFolder;

/**
 * {@link FolderInfo} - Simple class to hold folder information.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.8.1
 */
class FolderInfo {

    static FolderInfo getFolderInfo(String fullName, IMailFolderStorage folderStorage) throws OXException {
        if (folderStorage instanceof IMailFolderStorageEnhanced2) {
            IMailFolderStorageEnhanced2 enhanced2 = (IMailFolderStorageEnhanced2) folderStorage;
            int[] totalAndUnread = enhanced2.getTotalAndUnreadCounter(fullName);
            return new FolderInfo(totalAndUnread[0], totalAndUnread[1]);
        }

        if (folderStorage instanceof IMailFolderStorageEnhanced) {
            IMailFolderStorageEnhanced enhanced = (IMailFolderStorageEnhanced) folderStorage;
            int total = enhanced.getTotalCounter(fullName);
            int unread = enhanced.getUnreadCounter(fullName);
            return new FolderInfo(total, unread);
        }

        MailFolder folder = folderStorage.getFolder(fullName);
        return new FolderInfo(folder.getMessageCount(), folder.getUnreadMessageCount());
    }

    // --------------------------------------------------------------------------------------------------------------

    final int total;
    final int unread;

    FolderInfo(int total, int unread) {
        super();
        this.total = total;
        this.unread = unread;
    }

    @Override
    public String toString() {
        return new StringBuilder(32).append("{total=").append(total).append(", unread=").append(unread).append('}').toString();
    }

}

==> open-xchange-core_7.10.1.orig.tar.bz2: open-xchange-core-7.10.1/com.openexchange.server/src/com/openexchange/mail/json/actions/FolderInfo.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mail.json.actions;

import com.openexchange.exception.OXException;
import com.openexchange.mail.api.IMailFolderStorage;
import com.openexchange.mail.api.IMailFolderStorageEnhanced;
import com.openexchange.mail.api.IMailFolderStorageEnhanced2;
import com.openexchange.mail.dataobjects.MailFolder;

/**
 * {@link FolderInfo} - Simple class to hold folder information.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.8.1
 */
class FolderInfo {

    static FolderInfo getFolderInfo(String fullName, IMailFolderStorage folderStorage) throws OXException {
        IMailFolderStorageEnhanced2 storageEnhanced2 = folderStorage.supports(IMailFolderStorageEnhanced2.class);
        if (null != storageEnhanced2) {
            int[] totalAndUnread = storageEnhanced2.getTotalAndUnreadCounter(fullName);
            return new FolderInfo(totalAndUnread[0], totalAndUnread[1]);
        }

        IMailFolderStorageEnhanced storageEnhanced = folderStorage.supports(IMailFolderStorageEnhanced.class);
        if (null != storageEnhanced) {
            int total = storageEnhanced.getTotalCounter(fullName);
            int unread = storageEnhanced.getUnreadCounter(fullName);
            return new FolderInfo(total, unread);
        }

        MailFolder folder = folderStorage.getFolder(fullName);
        return new FolderInfo(folder.getMessageCount(), folder.getUnreadMessageCount());
    }

    // --------------------------------------------------------------------------------------------------------------

    final int total;
    final int unread;

    FolderInfo(int total, int unread) {
        super();
        this.total = total;
        this.unread = unread;
    }

    @Override
    public String toString() {
        return new StringBuilder(32).append("{total=").append(total).append(", unread=").append(unread).append('}').toString();
    }

}
